@@ -1,24 +1,14 @@
 from pydantic import BaseModel, Field
+from ai_kit.core.llms.google_genai_client import GoogleGenAI
 from typing import Dict, Optional
 import logging
 from ai_kit.core.llms.litellm_client import StructuredOutputClient
-from ai_kit.utils.prompts import load_prompt
-from ai_kit.config import CoreConfig
-from ai_kit.utils.fs import package_root
-import os
-import json
-from ai_kit.utils.fs import find_workspace_root
+from ai_kit.utils.fs import package_root, load_system_prompt
 
 logger = logging.getLogger(__name__)
 
 PACKAGE_ROOT = package_root()
 ROUTER_PROMPT_PATH = f"{PACKAGE_ROOT}/system_prompts/router.md"
-
-# -----------------------------
-# 1. DEFINE A SINGLE ROUTE
-# -----------------------------
-
-
 class RouteDefinition(BaseModel):
     """
     Defines an available route:
@@ -29,12 +19,6 @@ class RouteDefinition(BaseModel):
     name: str
     description: str
 
-
-# -----------------------------
-# 2. MANAGE A REGISTRY OF ROUTES
-# -----------------------------
-
-
 class RouteRegistry:
     """
     Manages a collection of RouteDefinition objects.
@@ -73,12 +57,6 @@ class RouteRegistry:
     def route_names(self):
         return list(self._routes.keys())
 
-
-# -----------------------------
-# 3. ROUTING DECISION MODEL
-# -----------------------------
-
-
 class RoutingDecision(BaseModel):
     """
     The structured output from the model indicating which route to use.
@@ -88,16 +66,6 @@ class RoutingDecision(BaseModel):
     confidence: float = Field(..., description="Confidence from 0.0 to 1.0")
     reasoning: str = Field(..., description="Brief explanation of the choice")
 
-
-# -----------------------------
-# 4. THE ROUTER
-# -----------------------------
-
-# llama-3.1-8B-instruct is much faster than gpt-4o
-# gpt-4o: 2.79, 1.87
-# llama-3.1-8B-instruct: 0.92, 0.87
-
-
 class Router:
     def __init__(
         self, route_registry: RouteRegistry, model: Optional[str] = None
@@ -113,7 +81,10 @@ class Router:
             model = "gpt-4o"  # Fallback to default
         
         self.model = model
-        self.client = StructuredOutputClient(model=model)
+        if model == "gemini-2.0-flash":
+            self.client = GoogleGenAI(model=model)
+        else:
+            self.client = StructuredOutputClient(model=model)
 
     def get_system_prompt(self) -> str:
         """
@@ -121,7 +92,7 @@ class Router:
         """
         # Insert the route list snippet
         route_list = self.registry.routes_prompt_snippet()
-        system_prompt = load_prompt(ROUTER_PROMPT_PATH)
+        system_prompt = load_system_prompt(ROUTER_PROMPT_PATH)
         assert system_prompt is not None and system_prompt.strip() != ""
         with_route_list = system_prompt.format(route_list=route_list)
         return with_route_list
@@ -140,7 +111,7 @@ class Router:
             {"role": "user", "content": system_prompt + "\n\n" + query},
         ]
         # Call the LLM client with a structured output request
-        decision = self.client.structured_output_completion(
+        decision: RoutingDecision = self.client.structured_output_completion(
             messages=messages,
             schema=RoutingDecision,
         )
@@ -150,8 +121,7 @@ class Router:
             logger.warning(
                 f"Unrecognized route chosen: {decision.route}. Falling back to default."
             )
-            # You can decide a default fallback
-            decision.route = "thinking_agent"
+            decision.route = "some_other_route"
             decision.reasoning += " [FELL BACK due to invalid route]"
             decision.confidence = 0.5
 
