@@ -5,8 +5,9 @@ import stat
 import importlib.resources
 from pathlib import Path
 from typing import Optional, List
-from ..config import CoreConfig
 
+# Standard project markers in order of preference
+WORKSPACE_MARKERS = [".git", ".gitignore", ".cursor", "pyproject.toml", "package.json"]
 
 class WorkspaceError(Exception):
     """Custom exception for workspace-related errors."""
@@ -79,16 +80,14 @@ def find_workspace_root(start_path: Optional[Path] = None) -> Path:
     else:
         current_path = start_path.resolve()
 
-    # Standard project markers in order of preference
-    root_markers = [CoreConfig.ROOT_DIR, ".gitignore"]
     for parent in [current_path] + list(current_path.parents):
         # Check each marker
-        for marker in root_markers:
+        for marker in WORKSPACE_MARKERS:
             if (parent / marker).exists():
                 return parent
 
     raise WorkspaceError(
-        "Workspace root not found. Ensure you are in a project with a .ai-kit directory. Run `ai-kit init` to automatically create one."
+        "Workspace root not found. Ensure you are in a project with standard project markers (.git, .gitignore, pyproject.toml, etc.)"
     )
 
 
@@ -241,4 +240,12 @@ def crawl_dir(dir_path: str, supported_extensions: List[str]) -> List[tuple[str,
                 abs_path = os.path.join(root, file)
                 rel_path = os.path.relpath(abs_path, dir_path)
                 paths.append((abs_path, rel_path))
-    return paths
\ No newline at end of file
+    return paths
+
+
+
+def load_system_prompt(path: str) -> str:
+    """Load a prompt file."""
+    from ai_kit.utils.dynamic_file_loader import DynamicFileLoader
+    file_loader = DynamicFileLoader()
+    return file_loader.load_file_content(path)
